@@ -71,6 +71,8 @@ const Profile::PropertyInfo Profile::DefaultPropertyNames[] = {
     , { SilenceSeconds, "SilenceSeconds" , GENERAL_GROUP , QVariant::Int }
     , { TerminalColumns, "TerminalColumns" , GENERAL_GROUP , QVariant::Int }
     , { TerminalRows, "TerminalRows" , GENERAL_GROUP , QVariant::Int }
+    , { TerminalMargin, "TerminalMargin" , GENERAL_GROUP , QVariant::Int }
+    , { TerminalCenter, "TerminalCenter" , GENERAL_GROUP , QVariant::Bool }
 
     // Appearance
     , { Font , "Font" , APPEARANCE_GROUP , QVariant::Font }
@@ -91,7 +93,7 @@ const Profile::PropertyInfo Profile::DefaultPropertyNames[] = {
     , { ScrollFullPage , "ScrollFullPage" , SCROLLING_GROUP , QVariant::Bool }
 
     // Terminal Features
-    , { EnableUrlHints , "EnableUrlHints" , TERMINAL_GROUP , QVariant::Bool }
+    , { UrlHintsModifiers , "UrlHintsModifiers" , TERMINAL_GROUP , QVariant::Int }
     , { BlinkingTextEnabled , "BlinkingTextEnabled" , TERMINAL_GROUP , QVariant::Bool }
     , { FlowControlEnabled , "FlowControlEnabled" , TERMINAL_GROUP , QVariant::Bool }
     , { BidiRenderingEnabled , "BidiRenderingEnabled" , TERMINAL_GROUP , QVariant::Bool }
@@ -107,6 +109,7 @@ const Profile::PropertyInfo Profile::DefaultPropertyNames[] = {
     , { WordCharacters , "WordCharacters" , INTERACTION_GROUP , QVariant::String }
     , { TripleClickMode , "TripleClickMode" , INTERACTION_GROUP , QVariant::Int }
     , { UnderlineLinksEnabled , "UnderlineLinksEnabled" , INTERACTION_GROUP , QVariant::Bool }
+    , { UnderlineFilesEnabled , "UnderlineFilesEnabled" , INTERACTION_GROUP , QVariant::Bool }
     , { OpenLinksByDirectClickEnabled , "OpenLinksByDirectClickEnabled" , INTERACTION_GROUP , QVariant::Bool }
     , { CtrlRequiredForDrag, "CtrlRequiredForDrag" , INTERACTION_GROUP , QVariant::Bool }
     , { DropUrlsAsText , "DropUrlsAsText" , INTERACTION_GROUP , QVariant::Bool }
@@ -164,6 +167,8 @@ FallbackProfile::FallbackProfile()
     setProperty(SilenceSeconds, 10);
     setProperty(TerminalColumns, 80);
     setProperty(TerminalRows, 24);
+    setProperty(TerminalMargin, 1);
+    setProperty(TerminalCenter, false);
     setProperty(MouseWheelZoomEnabled, true);
 
     setProperty(KeyBindings, "default");
@@ -176,9 +181,10 @@ FallbackProfile::FallbackProfile()
     setProperty(ScrollFullPage, false);
 
     setProperty(FlowControlEnabled, true);
-    setProperty(EnableUrlHints, false);
+    setProperty(UrlHintsModifiers, 0);
     setProperty(BlinkingTextEnabled, true);
-    setProperty(UnderlineLinksEnabled, false);
+    setProperty(UnderlineLinksEnabled, true);
+    setProperty(UnderlineFilesEnabled, false);
     setProperty(OpenLinksByDirectClickEnabled, false);
     setProperty(CtrlRequiredForDrag, true);
     setProperty(AutoCopySelectedText, false);
