@@ -63,39 +63,6 @@ using namespace Konsole;
 int Session::lastSessionId = 0;
 static bool show_disallow_certain_dbus_methods_message = true;
 
-// HACK This is copied out of QUuid::createUuid with reseeding forced.
-// Required because color schemes repeatedly seed the RNG...
-// ...with a constant.
-QUuid createUuid()
-{
-    static const int intbits = sizeof(int) * 8;
-    static int randbits = 0;
-    if (!randbits) {
-        int max = RAND_MAX;
-        do {
-            ++randbits;
-        } while ((max = max >> 1));
-    }
-
-    qsrand(uint(QDateTime::currentDateTimeUtc().toTime_t()));
-    qrand(); // Skip first
-
-    QUuid result;
-    uint* data = &(result.data1);
-    int chunks = 16 / sizeof(uint);
-    while (chunks--) {
-        uint randNumber = 0;
-        for (int filled = 0; filled < intbits; filled += randbits)
-            randNumber |= qrand() << filled;
-        *(data + chunks) = randNumber;
-    }
-
-    result.data4[0] = (result.data4[0] & 0x3F) | 0x80;        // UV_DCE
-    result.data3 = (result.data3 & 0x0FFF) | 0x4000;        // UV_Random
-
-    return result;
-}
-
 Session::Session(QObject* parent) :
     QObject(parent)
     , _shellProcess(0)
@@ -117,7 +84,7 @@ Session::Session(QObject* parent) :
     , _zmodemProgress(0)
     , _hasDarkBackground(false)
 {
-    _uniqueIdentifier = createUuid();
+    _uniqueIdentifier = QUuid::createUuid();
 
     //prepare DBus communication
     new SessionAdaptor(this);
@@ -264,7 +231,7 @@ void Session::setArguments(const QStringList& arguments)
 
 void Session::setInitialWorkingDirectory(const QString& dir)
 {
-    _initialWorkingDir = KShell::tildeExpand(ShellCommand::expand(dir));
+    _initialWorkingDir = validDirectory(KShell::tildeExpand(ShellCommand::expand(dir)));
 }
 
 QString Session::currentWorkingDirectory()
@@ -426,7 +393,7 @@ void Session::run()
         qWarning() << "No command line arguments specified.";
     }
     if (_uniqueIdentifier.isNull()) {
-        _uniqueIdentifier = createUuid();
+        _uniqueIdentifier = QUuid::createUuid();
     }
 
     const int CHOICE_COUNT = 3;
@@ -574,10 +541,13 @@ QString Session::userTitle() const
 }
 void Session::setTabTitleFormat(TabTitleContext context , const QString& format)
 {
-    if (context == LocalTabTitle)
+    if (context == LocalTabTitle) {
         _localTabTitleFormat = format;
-    else if (context == RemoteTabTitle)
+        ProcessInfo* process = getProcessInfo();
+        process->setUserNameRequired(format.contains(QLatin1String("%u")));
+    } else if (context == RemoteTabTitle) {
         _remoteTabTitleFormat = format;
+    }
 }
 QString Session::tabTitleFormat(TabTitleContext context) const
 {
@@ -1050,21 +1020,59 @@ bool Session::isRemote()
 
 QString Session::getDynamicTitle()
 {
-    // update current directory from process
-    updateWorkingDirectory();
 
     ProcessInfo* process = getProcessInfo();
 
     // format tab titles using process info
     bool ok = false;
-    QString title;
     if (process->name(&ok) == "ssh" && ok) {
         SSHProcessInfo sshInfo(*process);
-        title = sshInfo.format(tabTitleFormat(Session::RemoteTabTitle));
-    } else {
-        title = process->format(tabTitleFormat(Session::LocalTabTitle));
+        return sshInfo.format(tabTitleFormat(Session::RemoteTabTitle));
     }
 
+    /*
+     * Parses an input string, looking for markers beginning with a '%'
+     * character and returns a string with the markers replaced
+     * with information from this process description.
+     * <br>
+     * The markers recognized are:
+     * <ul>
+     * <li> %u - Name of the user which owns the process. </li>
+     * <li> %n - Replaced with the name of the process.   </li>
+     * <li> %d - Replaced with the last part of the path name of the
+     *      process' current working directory.
+     *
+     *      (eg. if the current directory is '/home/bob' then
+     *      'bob' would be returned)
+     * </li>
+     * <li> %D - Replaced with the current working directory of the process. </li>
+     * </ul>
+     */
+    QString title = tabTitleFormat(Session::LocalTabTitle);
+    // search for and replace known marker
+    title.replace(QLatin1String("%u"), process->userName());
+    title.replace(QLatin1String("%h"), process->localHost());
+    title.replace(QLatin1String("%n"), process->name(&ok));
+
+    QString dir = _reportedWorkingUrl.toLocalFile();
+    if (dir.isEmpty()) {
+        // update current directory from process
+        updateWorkingDirectory();
+        dir = process->validCurrentDir();
+    }
+
+    if (title.contains(QLatin1String("%D"))) {
+        QString homeDir = process->userHomeDir();
+        QString tempDir = dir;
+        // Change User's Home Dir w/ ~ only at the beginning
+        if (tempDir.startsWith(homeDir)) {
+            tempDir.remove(0, homeDir.length());
+            tempDir.prepend('~');
+        }
+        title.replace(QLatin1String("%D"), tempDir);
+    }
+    title.replace(QLatin1String("%d"), process->formatShortDir(dir));
+
     return title;
 }
 
@@ -1512,6 +1520,21 @@ void Session::restoreSession(KConfigGroup& group)
     if (!value.isEmpty()) setCodec(value.toUtf8());
 }
 
+QString Session::validDirectory(const QString& dir) const
+{
+    QString validDir = dir;
+    if (validDir.isEmpty()) {
+        validDir = QDir::currentPath();
+    }
+
+    const QFileInfo fi(validDir);
+    if (!fi.exists() || !fi.isDir()) {
+        validDir = QDir::homePath();
+    }
+
+    return validDir;
+}
+
 SessionGroup::SessionGroup(QObject* parent)
     : QObject(parent), _masterMode(0)
 {
