@@ -20,6 +20,7 @@
 
 // Own
 #include "SessionController.h"
+#include "ProfileManager.h"
 
 // Qt
 #include <QApplication>
@@ -99,6 +100,8 @@ SessionController::SessionController(Session* session , TerminalDisplay* view, Q
     , _profileList(0)
     , _previousState(-1)
     , _searchFilter(0)
+    , _urlFilter(0)
+    , _fileFilter(0)
     , _copyInputToAllTabsAction(0)
     , _findAction(0)
     , _findNextAction(0)
@@ -140,11 +143,11 @@ SessionController::SessionController(Session* session , TerminalDisplay* view, Q
     view->installEventFilter(this);
     view->setSessionController(this);
 
-    // install filter on the view to highlight URLs
-    _view->filterChain()->addFilter(new UrlFilter);
+    // install filter on the view to highlight URLs and files
+    updateFilterList(SessionManager::instance()->sessionProfile(_session));
 
-    // install filter on the view to highlight Files
-    _view->filterChain()->addFilter(new FileFilter(_session));
+    // listen for changes in session, we might need to change the enabled filters
+    connect(ProfileManager::instance(), &Konsole::ProfileManager::profileChanged, this, &Konsole::SessionController::updateFilterList);
 
     // listen for session resize requests
     connect(_session.data(), &Konsole::Session::resizeRequest, this, &Konsole::SessionController::sessionResizeRequest);
@@ -224,17 +227,13 @@ void SessionController::trackOutput(QKeyEvent* event)
 {
     Q_ASSERT(_view->screenWindow());
 
-    // jump to the end of the history buffer unless the key pressed
-    // is one of the three main modifiers, as these are used to select
-    // the selection mode (eg. Ctrl+Alt+<Left Click> for column/block selection)
-    switch (event->key()) {
-    case Qt::Key_Shift:
-    case Qt::Key_Control:
-    case Qt::Key_Alt:
-        break;
-    default:
-        _view->screenWindow()->setTrackOutput(true);
+    // Only jump to the bottom if the user actually typed something in,
+    // not if the user e. g. just pressed a modifier.
+    if (event->text().isEmpty() && event->modifiers()) {
+        return;
     }
+
+    _view->screenWindow()->setTrackOutput(true);
 }
 void SessionController::interactionHandler()
 {
@@ -451,25 +450,23 @@ void SessionController::sendBackgroundColor()
 
 bool SessionController::eventFilter(QObject* watched , QEvent* event)
 {
-    if (watched == _view) {
-        if (event->type() == QEvent::FocusIn) {
-            // notify the world that the view associated with this session has been focused
-            // used by the view manager to update the title of the MainWindow widget containing the view
-            emit focused(this);
+    if (event->type() == QEvent::FocusIn && watched == _view) {
+        // notify the world that the view associated with this session has been focused
+        // used by the view manager to update the title of the MainWindow widget containing the view
+        emit focused(this);
 
-            // when the view is focused, set bell events from the associated session to be delivered
-            // by the focused view
+        // when the view is focused, set bell events from the associated session to be delivered
+        // by the focused view
 
-            // first, disconnect any other views which are listening for bell signals from the session
-            disconnect(_session.data(), &Konsole::Session::bellRequest, 0, 0);
-            // second, connect the newly focused view to listen for the session's bell signal
-            connect(_session.data(), &Konsole::Session::bellRequest, _view.data(), &Konsole::TerminalDisplay::bell);
+        // first, disconnect any other views which are listening for bell signals from the session
+        disconnect(_session.data(), &Konsole::Session::bellRequest, 0, 0);
+        // second, connect the newly focused view to listen for the session's bell signal
+        connect(_session.data(), &Konsole::Session::bellRequest, _view.data(), &Konsole::TerminalDisplay::bell);
 
-            if (_copyInputToAllTabsAction && _copyInputToAllTabsAction->isChecked()) {
-                // A session with "Copy To All Tabs" has come into focus:
-                // Ensure that newly created sessions are included in _copyToGroup!
-                copyInputToAllTabs();
-            }
+        if (_copyInputToAllTabsAction && _copyInputToAllTabsAction->isChecked()) {
+            // A session with "Copy To All Tabs" has come into focus:
+            // Ensure that newly created sessions are included in _copyToGroup!
+            copyInputToAllTabs();
         }
     }
 
@@ -744,6 +741,7 @@ void SessionController::setupExtraActions()
 void SessionController::switchProfile(Profile::Ptr profile)
 {
     SessionManager::instance()->setSessionProfile(_session, profile);
+    updateFilterList(profile);
 }
 
 void SessionController::prepareSwitchProfileMenu()
@@ -1068,6 +1066,34 @@ void SessionController::searchClosed()
     searchHistory(false);
 }
 
+void SessionController::updateFilterList(Profile::Ptr profile)
+{
+    if (profile != SessionManager::instance()->sessionProfile(_session)) {
+        return;
+    }
+
+    bool underlineFiles = profile->underlineFilesEnabled();
+
+    if (!underlineFiles && _fileFilter) {
+        _view->filterChain()->removeFilter(_fileFilter);
+        delete _fileFilter;
+        _fileFilter = nullptr;
+    } else if (underlineFiles && !_fileFilter) {
+        _fileFilter = new FileFilter(_session);
+        _view->filterChain()->addFilter(_fileFilter);
+    }
+
+    bool underlineLinks = profile->underlineLinksEnabled();
+    if (!underlineLinks && _urlFilter) {
+        _view->filterChain()->removeFilter(_urlFilter);
+        delete _urlFilter;
+        _urlFilter = nullptr;
+    } else if (underlineLinks && !_urlFilter) {
+        _urlFilter = new UrlFilter();
+        _view->filterChain()->addFilter(_urlFilter);
+    }
+}
+
 void SessionController::setSearchStartToWindowCurrentLine()
 {
     setSearchStartTo(-1);
